==> kolourpaint-17.04.3-1-src.tar.xz: kolourpaint-17.04.3/commands/imagelib/transforms/kpTransformFlipCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransformFlipCommand_H
#define kpTransformFlipCommand_H


#include "commands/kpCommand.h"


class kpTransformFlipCommand : public kpCommand
{
public:
    kpTransformFlipCommand (bool actOnSelection,
        bool horiz, bool vert,
        kpCommandEnvironment *environ);

    virtual ~kpTransformFlipCommand ();

    virtual QString name () const;

    virtual SizeType size () const;

    virtual void execute ();
    virtual void unexecute ();

private:
    void flip ();

    bool m_actOnSelection;
    bool m_horiz, m_vert;
};


#endif  // kpTransformFlipCommand_H

==> kolourpaint-17.08.3-1-src.tar.xz: kolourpaint-17.08.3/commands/imagelib/transforms/kpTransformFlipCommand.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef kpTransformFlipCommand_H
#define kpTransformFlipCommand_H


#include "commands/kpCommand.h"


class kpTransformFlipCommand : public kpCommand
{
public:
    kpTransformFlipCommand (bool actOnSelection,
        bool horiz, bool vert,
        kpCommandEnvironment *environ);

    virtual ~kpTransformFlipCommand ();

    QString name () const Q_DECL_OVERRIDE;

    SizeType size () const Q_DECL_OVERRIDE;

    void execute () Q_DECL_OVERRIDE;
    void unexecute () Q_DECL_OVERRIDE;

private:
    void flip ();

    bool m_actOnSelection;
    bool m_horiz, m_vert;
};


#endif  // kpTransformFlipCommand_H
